@@ -212,8 +212,8 @@ class Funicorn():
                 f"{colored_worker_name(f'WORKER-{worker_info.wrk_id}')} ready state: {is_ready}")
             if not is_ready:
                 self.logger.error(
-                    f"{colored_worker_name(f'WORKER-{worker_info.wrk_id}')} cannot start. EXIT!")
-                exit()
+                    f"{colored_worker_name(f'WORKER-{worker_info.wrk_id}')} cannot start.")
+                # exit()
 
     def _start_task_distributations(self):
         '''Distribute task to wrk_queue'''
