@@ -9,6 +9,7 @@ from http import HTTPStatus
 import traceback
 
 from .exceptions import NotSupportedInputFile, MaxFileSizeExeeded, InitializationError
+from .exceptions import DownloadURLError
 from .utils import colored_network_name, check_all_ps_status
 from .logger import get_logger
 from .stat import Statistic
@@ -63,6 +64,16 @@ class HttpAPI(threading.Thread):
             resp.status_code = HTTPStatus.BAD_REQUEST
             return resp
 
+        @app.errorhandler(DownloadURLError)
+        def wrong_request_params(error):
+            resp = jsonify({
+                "error_code": error.status_code,
+                "error_message": error.message,
+                "results": []
+            })
+            resp.status_code = HTTPStatus.INTERNAL_SERVER_ERROR
+            return resp
+
         @app.errorhandler(HTTPStatus.INTERNAL_SERVER_ERROR)
         def internal_server_error(error):
             resp = jsonify({
@@ -103,7 +114,7 @@ class HttpAPI(threading.Thread):
                     img = convert_bytes_to_img_arr(img_bytes)
                     results = self.funicorn_app.predict_img_bytes(img)
                     if results is ResponseStatus.CANNOT_DOWNLOAD_URL:
-                        abort(HTTPStatus.BAD_REQUEST)
+                        abort(DownloadURLError)
                     else:
                         final_res = results
                     final_res = final_res if len(final_res) != 0 else []
@@ -241,7 +252,7 @@ class HttpAPI(threading.Thread):
                     url = request.args['url']
                     results = self.funicorn_app.predict(url)
                     if results is ResponseStatus.CANNOT_DOWNLOAD_URL:
-                        abort(HTTPStatus.BAD_REQUEST)
+                        raise DownloadURLError(message='Cannot download data from url!')
                     else:
                         final_res = results
                     resp = jsonify({
@@ -264,10 +275,10 @@ class HttpAPI(threading.Thread):
                 self.stat.increment('crashes')
                 abort(HTTPStatus.REQUEST_ENTITY_TOO_LARGE)
 
-            except Exception as e:
-                self.stat.increment('crashes')
-                self.logger.error(traceback.format_exc())
-                abort(HTTPStatus.INTERNAL_SERVER_ERROR)
+            # except Exception as e:
+            #     self.stat.increment('crashes')
+            #     self.logger.error(traceback.format_exc())
+            #     abort(HTTPStatus.INTERNAL_SERVER_ERROR)
 
         @app.route('/', methods=['GET'])
         def index():
